@@ -1,6 +1,8 @@
 import json
 import os
+import sys
 from .protocols import HFE
+import importlib
 
 ## Classes for Extensions. Such as, the JSONIndexedSecurity.
 class Extension:
@@ -73,38 +75,33 @@ class JustASimpleWebServerExtension(Extension):
         self.server.getHook("http_handleGET").addTopFunction(self.topGET,0) ## Not to make it a habit, but priority number 0 is kind of necessary for webserver extensions.
         self.server.getHook("http_handle").addTopFunction(self.filter_reqloc)
         self.server.getHook("httpfailure").setDefaultFunction(self.fail)
+        return "jaswse"
     def fail(self,incoming,outgoing,event):
         if event==HFE.FILENOTFOUND:
             outgoing.setStatus(404)
             outgoing.setContent("The file you does be lookin' for don't exist.")
-            outgoing.send()
     def topGET(self,incoming,outgoing): ## Copycatted from server.py/SimpleHTTPServer
         baselocale=os.path.basename(incoming.location)
         locale=incoming.location
-        print(locale)
         if baselocale=="":
             if os.path.isfile(locale+self.index):
                 outgoing.setStatus(200)
                 outgoing.setFile(locale+self.index)
-                outgoing.send()
             else:
                 self.server.getHook("httpfailure").call(incoming,outgoing,HFE.FILENOTFOUND) ## Build utilities should intercept this.
         else:
             if os.path.isfile(locale):
                 outgoing.setStatus(200)
                 outgoing.setFile(locale)
-                outgoing.send()
             elif os.path.isdir(locale) and os.path.exists(locale+"/"+self.index):
                 outgoing.setStatus(200)
                 outgoing.setFile(locale+"/"+self.index)
-                outgoing.send()
             elif os.path.isfile(locale+".html"):
                 outgoing.setStatus(200)
                 outgoing.setFile(locale+".html")
-                outgoing.send()
             else:
-                print("Failure.")
                 self.server.getHook("httpfailure").call(incoming,outgoing,HFE.FILENOTFOUND)
+        
     def filter_reqloc(self,incoming,outgoing):
         '''Sterilize the location of the request. Do not touch unless you know what your doing.'''
         realpos=incoming.location
@@ -112,5 +109,33 @@ class JustASimpleWebServerExtension(Extension):
             realpos=realpos[1:]
         realpos=self.sitedir+realpos
         realpos=realpos.replace("/../","/") ## Make sure unsavory characters can't hack you out by sending get requests with ../ as the location
-        incoming.location=os.path.abspath(realpos+("index.html" if incoming.location[-1]=="/" else "")) ## All later tasks will also use this new safe version. Turns urls like "../../../important.fileextension to ./important.fileextension, obviously not as damaging unless you made an important document public.
+        incoming.location=realpos
+        print("Filtered the request location")
         return True ## Don't ever forget return in a top function.
+
+class PyHP(Extension):
+    def uponAddToServer(self,index="index"):
+        print("Added to server")
+        self.index=index
+        self.server.getHook("http_handle").addFunction(self.handle)
+        return "pyhp" ## Extensions should always return a name
+    def handle(self,incoming,outgoing):
+        try:
+            locale=None
+            if incoming.location[-3:]==".py":
+                locale=incoming.location[:-3]
+            if os.path.exists(incoming.location+".py"):
+                locale=incoming.location
+            if incoming.location[-1]=="/" and os.path.exists(incoming.location+self.index+".py"):
+                locale=incoming.location+self.index
+            if locale:
+                i=importlib.import_module(os.path.relpath(locale).replace("/","."))
+                if incoming.type=="GET" and hasattr(i,"handle_get"):
+                    data,status=i.handle_get(incoming) ## The PyHP file should return HTML and HTTP status
+                    outgoing.setStatus(status)
+                    outgoing.setContent(data)
+                elif incoming.type=="POST" and hasattr(i,"handle_post"):
+                    status=i.handle_post(incoming) ## For POST, PyHP should return the HTTP status code
+                    outgoing.setStatus(status)
+        except Exception as e:
+            print(e)
