@@ -19,6 +19,15 @@ use except maybe creating your own HTTP based servers.'''
                 self.getHook("http_handle"+x).addTopFunction(self.__getattribute__("top"+x))
         if hasattr(self,"topHTTPFailure"):
             self.getHook("httpfailure").addTopFunction(self.topHTTPFailure)
+        print(self.hooks)
+        self.getHook("init").addFunction(self.initialify)
+        print([x.__name__ for x in self.getHook("init").functions])
+    def initialify(self):
+        print("Adding the send hook")
+        self.getHook("http_handle").addFunction(self.send)
+    def send(self,incoming,outgoing):
+        print("Sent!")
+        outgoing.send() ## Assume that status and other information have already been set.
 
 
 class SimpleWebServer(HTTPServer):
