@@ -2,7 +2,7 @@
 ## This software program is governed under the terms of the MIT license
 ## This concludes the license section, and I don't even know why I bothered to add this.
 
-import socket
+import socket,time
 
 
 class Data:
@@ -12,19 +12,23 @@ class TCPSocket:
     '''The bottom-level socket.socket wrapper for Serverutils. It is advised
 to use ServerSocket, ClientSocket, and ClientConnection instead,
 as they add a nice padding.'''
-    def __init__(self,host=None,port=None,blocking=False,sckt=None):
+    def __init__(self,host=None,port=None,blocking=False,sckt=None,recvtries=10):
         self.sckt=sckt or socket.socket(socket.AF_INET,socket.SOCK_STREAM)
         self.sckt.setblocking(blocking)
+        self.recvtries=recvtries
         self.host=host
         self.port=port
         self.blocking=blocking
         self.datacapable=True
     def connect(self):
+        '''For clients, connect to a URL over TCP'''
         self.sckt.setblocking(True)
         self.sckt.connect((self.host,self.port))
     def bind(self):
+        '''For servers, bind to the specified address and port in the object definition'''
         self.sckt.bind((self.host,self.port))
     def listen(self,mxnum=5):
+        '''For servers, listen for connections with a default maximum connection cache size of 5'''
         self.sckt.listen(mxnum)
     def accept(self):
         connection, address=self.sckt.accept()
@@ -34,19 +38,32 @@ as they add a nice padding.'''
         self.listen(mxnum)
     def recv(self,numbytes=Data.STDCHUNKSIZE):
         '''Recieve data. Normal recieve size is half a kilobyte, which is a working chunk size for recvall.'''
-        if self.datacapable==False:
-            raise Exception
-        data = self.socket.recv(numbytes)
-        if data=="":
+        if self.datacapable==False: ## Another ridiculous error
+            horseradishponieskillingdorkmeggledharbingshubbles(CertainlyNeverGoingToBeARealName)
+        data = self.sckt.recv(numbytes) ## Credit to the creator of this file for making a stupid mistake and using self.socket rather than self.sckt.
+        if data==b"":
             self.datacapable=False
         return data
     def recvall(self,chunks=Data.STDCHUNKSIZE):
         '''Recieve all possible data, with a chunk size of half a kilobyte, default.'''
         data=bytes()
         self.sckt.setblocking(False)
+        tries=0
         try:
             while 1:
-                data+=self.recv(chunks)
+                try:
+                    p=self.recv(chunks)
+                    data+=p
+                    if len(p)>0 and len(p)!=Data.STDCHUNKSIZE: ## All the data is recieved!
+                        tries=self.recvtries+1
+                        raise Exception
+                    tries=0 ## If some of the data is recieved successfully, tries=0.
+                except:
+                    if tries>self.recvtries or data!=b"":
+                        raise Exception
+                    else:
+                        tries+=1
+                        time.sleep(0.01)
         except:
             return data
     def recvtext(self,chunks=Data.STDCHUNKSIZE):
@@ -66,7 +83,6 @@ as they add a nice padding.'''
     def close(self):
         self.sckt.shutdown(1)
         self.sckt.close()
-        self.sckt.close()
     def setblocking(self,blocking):
         self.blocking=blocking
         self.sckt.setblocking(blocking)
@@ -78,24 +94,20 @@ class ClientConnection:
         self.socket=sckt
         self.clidata=clidata
         self.blocking=blocking
-    def recieve(self,rcv=Data.STDCHUNKSIZE):
+    def recv(self,rcv=Data.STDCHUNKSIZE):
         '''Recieve an amount of data from the client, as a bytes object'''
         return self.socket.recv(rcv)
-    def recievetext(self,rcv=Data.STDCHUNKSIZE):
+    def recvtext(self,rcv=Data.STDCHUNKSIZE):
         '''Recieve all data, and return it as a string'''
         return self.recieve(rcv).decode()
-    def recieveall(self,chunks=Data.STDCHUNKSIZE):
+    def recvall(self,chunks=Data.STDCHUNKSIZE):
         '''Recieve all available data, and return it as a bytes object.'''
-        data="".encode()
-        try:
-            while 1:
-                data+=self.recieve(chunks)
-        except: pass
+        data=self.socket.recvall(chunks)
         return data
     def sendfile(self,filename):
         '''Send a file.'''
         file=open(filename,"rb")
-        self.socket.sendall(file.read())
+        self.socket.send(file.read())
         file.close()
     def sendtext(self,data):
         '''Send text data'''
@@ -105,7 +117,6 @@ class ClientConnection:
         self.socket.send(data)
     def close(self):
         '''Completely close the socket and end the connection'''
-        self.socket.shutdown(1)
         self.socket.close()
 
 class ServerSocket(TCPSocket):
